==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/drivers_8h.js <==
var drivers_8h =
[
    [ "plbuf_bop", "drivers_8h.html#aae04ad62355c3a91fd93b7bfce7b49a7", null ],
    [ "plbuf_eop", "drivers_8h.html#a3e7cf1e07edf8f26ad11eddc9ada26dc", null ],
    [ "plbuf_esc", "drivers_8h.html#ae5131a0ffecc9826cb6ecfe40f096d6a", null ],
    [ "plbuf_init", "drivers_8h.html#ad9e6b3b1479cd7e2d25046f8f82f4952", null ],
    [ "plbuf_line", "drivers_8h.html#a7ac3cc47bf52917bcf01bb4e1a06f870", null ],
    [ "plbuf_polyline", "drivers_8h.html#a6f7823ce7862e60b817954c1f9842c9f", null ],
    [ "plbuf_restore", "drivers_8h.html#a4320599305a969571f4807dad3c9b07c", null ],
    [ "plbuf_save", "drivers_8h.html#a24123befa8ab7b32453afef5f2158e0a", null ],
    [ "plbuf_state", "drivers_8h.html#a04fc5b733e9276237fbc0504ad2913b0", null ],
    [ "plbuf_switch", "drivers_8h.html#ab99f4584f81ede6fbf759adf119c7908", null ],
    [ "plbuf_tidy", "drivers_8h.html#a8380d3bdc75eaaccdc69f3787f94c6d5", null ],
    [ "plD_dispatch_init_aqt", "drivers_8h.html#a1dd3e763078e0cfd82fc4cede1366a2f", null ],
    [ "plD_dispatch_init_bmp", "drivers_8h.html#a1f42845a31a88e8e144f72292b3183fb", null ],
    [ "plD_dispatch_init_bmpqt", "drivers_8h.html#a4062d0c531ed86d131ca59ecb6eab6c6", null ],
    [ "plD_dispatch_init_cgm", "drivers_8h.html#ad2370d582e90e5d9391ebb40fecc9f63", null ],
    [ "plD_dispatch_init_conex", "drivers_8h.html#ae9eb05e28a7d13d7d03e35e9177c636d", null ],
    [ "plD_dispatch_init_dg", "drivers_8h.html#adeeb1088830db818f76719d48a0835ff", null ],
    [ "plD_dispatch_init_epscairo", "drivers_8h.html#a572957dd71374a028b5ad116d3eece58", null ],
    [ "plD_dispatch_init_epsqt", "drivers_8h.html#a99a16338347aad1e7449b3a8d141cda8", null ],
    [ "plD_dispatch_init_extcairo", "drivers_8h.html#a8ca0406b19d7147104f78445e45b9b41", null ],
    [ "plD_dispatch_init_extqt", "drivers_8h.html#ab6e8ef8442c14ceb04124a0ae2ff6b0b", null ],
    [ "plD_dispatch_init_gcw", "drivers_8h.html#a764bd0d80c70a1483b84c4d204d715b0", null ],
    [ "plD_dispatch_init_gif", "drivers_8h.html#a5b230a0fcfc5a3e0cd2adb40799180ee", null ],
    [ "plD_dispatch_init_gnome", "drivers_8h.html#ab2c7d4442a92e98d13ac05969a6860d9", null ],
    [ "plD_dispatch_init_hp7470", "drivers_8h.html#ae0f4dc187b24ece7d02ff28f1b4c0638", null ],
    [ "plD_dispatch_init_hp7580", "drivers_8h.html#a5c2397ac27d2d4792e28bbf2ba0c413c", null ],
    [ "plD_dispatch_init_hpgl", "drivers_8h.html#a1d9a541684ba33b2ac4cd996428e700d", null ],
    [ "plD_dispatch_init_imp", "drivers_8h.html#ad8346a073fc13e4796358d58c906b584", null ],
    [ "plD_dispatch_init_jpeg", "drivers_8h.html#aae1abaa1ae115790e0d5aff2238f6b93", null ],
    [ "plD_dispatch_init_jpg", "drivers_8h.html#a4d0257039d8fbf6ba38f7ca715cce9f2", null ],
    [ "plD_dispatch_init_jpgqt", "drivers_8h.html#a3062b1d4c194820370e8b42c64ddff23", null ],
    [ "plD_dispatch_init_ljii", "drivers_8h.html#a6b7ab09329f80640c21000ab9e159527", null ],
    [ "plD_dispatch_init_ljiip", "drivers_8h.html#a40b8238c3f811916642ec6b0af18bbff", null ],
    [ "plD_dispatch_init_mac1", "drivers_8h.html#a7fd1ea24b4c7302e86776740bacef9f3", null ],
    [ "plD_dispatch_init_mac8", "drivers_8h.html#a03f1b3fe582a0020338af2829f014891", null ],
    [ "plD_dispatch_init_mem", "drivers_8h.html#a67f4d05ad2d4db16d2e893feafbc33db", null ],
    [ "plD_dispatch_init_memcairo", "drivers_8h.html#a3e723b08dc17e693d88c3c94a319eef0", null ],
    [ "plD_dispatch_init_memqt", "drivers_8h.html#aff1942bf49686ddb0d2f83b67cddf875", null ],
    [ "plD_dispatch_init_mgr", "drivers_8h.html#a4d26f5db27dd963b222b914fe7847b7f", null ],
    [ "plD_dispatch_init_mskermit", "drivers_8h.html#a3cb65385f70882ee3f75e415df5004f8", null ],
    [ "plD_dispatch_init_ntk", "drivers_8h.html#a5491405dbf712573a0a84a2a27b6d0ee", null ],
    [ "plD_dispatch_init_null", "drivers_8h.html#a4f69c62a1b6fed53e9a93076adebd89d", null ],
    [ "plD_dispatch_init_nx", "drivers_8h.html#adc5c16c5a3b9ebb4163f6241c5c1ee80", null ],
    [ "plD_dispatch_init_os2", "drivers_8h.html#a92804a83fdc1d63a3ce4a636249d302b", null ],
    [ "plD_dispatch_init_pbm", "drivers_8h.html#a51cd8861d7381f59ddc07179a930cc31", null ],
    [ "plD_dispatch_init_pdf", "drivers_8h.html#a263a541692dfe644c10d499513248d15", null ],
    [ "plD_dispatch_init_pdfcairo", "drivers_8h.html#aa502a88f00f7811379e1815ccb4dc9e2", null ],
    [ "plD_dispatch_init_pdfqt", "drivers_8h.html#a96f4eac8f7aaadfc0e7e14e3c28a065e", null ],
    [ "plD_dispatch_init_plm", "drivers_8h.html#af9aff741079c9e244d5befa19e282b06", null ],
    [ "plD_dispatch_init_png", "drivers_8h.html#ab75a4531f6991f45527038c884d3e9ae", null ],
    [ "plD_dispatch_init_pngcairo", "drivers_8h.html#ae92cfcea34206e50c1f348bf5a7cab24", null ],
    [ "plD_dispatch_init_pngqt", "drivers_8h.html#a117e5dda7fdf96287d823048aa87faec", null ],
    [ "plD_dispatch_init_ppmqt", "drivers_8h.html#a0ebb7f8a5d527714eb0e61386a160737", null ],
    [ "plD_dispatch_init_psc", "drivers_8h.html#a35794dc16d2622504190642b1b44c811", null ],
    [ "plD_dispatch_init_pscairo", "drivers_8h.html#ad5eddd212d165f2593a750142bdd3beb", null ],
    [ "plD_dispatch_init_psm", "drivers_8h.html#a8e9d129cfa3d1baa697f2659f092e3e4", null ],
    [ "plD_dispatch_init_pstex", "drivers_8h.html#a5a885f0fd5006f13c3a0cc6c0d99f0c5", null ],
    [ "plD_dispatch_init_psttfc", "drivers_8h.html#a6bf017d91756e4a3b9d00fd8ce00157e", null ],
    [ "plD_dispatch_init_psttfm", "drivers_8h.html#a67198a37c43e5c73662c16adcf32f288", null ],
    [ "plD_dispatch_init_qtwidget", "drivers_8h.html#ac0db04e91dac28bcc98a2effd3e6b8a3", null ],
    [ "plD_dispatch_init_svg", "drivers_8h.html#a781b47baccdb0fe6b2c0f86549de22b7", null ],
    [ "plD_dispatch_init_svgcairo", "drivers_8h.html#a1879d7f70ad6a5c77d928b9a29c58bf7", null ],
    [ "plD_dispatch_init_svgqt", "drivers_8h.html#a5fcf3fd321348aaa999ae8497067ea4e", null ],
    [ "plD_dispatch_init_tek4107f", "drivers_8h.html#aa4ea1f804483b703ddf627e7af51c664", null ],
    [ "plD_dispatch_init_tek4107t", "drivers_8h.html#a81f7fad7174fc8a0b0fdcba629c4c18d", null ],
    [ "plD_dispatch_init_tekf", "drivers_8h.html#adfa3674aeb382266ad39caeb3c0769d4", null ],
    [ "plD_dispatch_init_tekt", "drivers_8h.html#abed6f00fd63bd0db1bd6247bb13be36c", null ],
    [ "plD_dispatch_init_tiff", "drivers_8h.html#a8af2d7eeabcf5919a55fd6f1a99de964", null ],
    [ "plD_dispatch_init_tiffqt", "drivers_8h.html#ab013b8c4f62c7614ff23a11a7073e788", null ],
    [ "plD_dispatch_init_tk", "drivers_8h.html#a23f2027a53580bef3fdf644cff59a546", null ],
    [ "plD_dispatch_init_tkwin", "drivers_8h.html#a3f2e204449ada39332146b4ad295c62e", null ],
    [ "plD_dispatch_init_versaterm", "drivers_8h.html#a7de2d864179694955a6215c7ad920bb7", null ],
    [ "plD_dispatch_init_vga", "drivers_8h.html#afc9cfbdf6cd418f0b27c096575563a13", null ],
    [ "plD_dispatch_init_vlt", "drivers_8h.html#a759265ae5fc18bc288b8c130f916a83c", null ],
    [ "plD_dispatch_init_win3", "drivers_8h.html#a945629beb6b91def6bf56e90bbbd2013", null ],
    [ "plD_dispatch_init_wincairo", "drivers_8h.html#a19fb6c19ab899d28508265cce95b7e1b", null ],
    [ "plD_dispatch_init_wingcc", "drivers_8h.html#a2b7e1212a714523a0f8a69116efcc457", null ],
    [ "plD_dispatch_init_wxpng", "drivers_8h.html#a943b765ed6013ba7dba377f8f558ff86", null ],
    [ "plD_dispatch_init_wxwidgets", "drivers_8h.html#a372b75bf2e0b7b185b0ef44933b1e730", null ],
    [ "plD_dispatch_init_xcairo", "drivers_8h.html#a08d56c4df48e49adef57ff3410fd4d33", null ],
    [ "plD_dispatch_init_xfig", "drivers_8h.html#a7b3cadd1f9bb676fc12b3cc3d96d0be3", null ],
    [ "plD_dispatch_init_xterm", "drivers_8h.html#aeedd3dc8e53a9f301559a82a9de9ac53", null ],
    [ "plD_dispatch_init_xw", "drivers_8h.html#aa754ac9324e9e8c68c6fed27c9efa204", null ],
    [ "plRemakePlot", "drivers_8h.html#a1f4b01b8bacb7f80e2e1b261c0acbdf7", null ]
];

==> plplot-5.12.0.tar.gz: plplot-5.12.0/doc/doxygen/html/drivers_8h.js <==
var drivers_8h =
[
    [ "plbuf_bop", "drivers_8h.html#aae04ad62355c3a91fd93b7bfce7b49a7", null ],
    [ "plbuf_clip", "drivers_8h.html#aac1e6ac733fde1ac09d2a3d51dbd4dc9", null ],
    [ "plbuf_di", "drivers_8h.html#a31a980925f9b151dbd62e7240789fb3f", null ],
    [ "plbuf_eop", "drivers_8h.html#a3e7cf1e07edf8f26ad11eddc9ada26dc", null ],
    [ "plbuf_esc", "drivers_8h.html#ae5131a0ffecc9826cb6ecfe40f096d6a", null ],
    [ "plbuf_init", "drivers_8h.html#ad9e6b3b1479cd7e2d25046f8f82f4952", null ],
    [ "plbuf_line", "drivers_8h.html#a7ac3cc47bf52917bcf01bb4e1a06f870", null ],
    [ "plbuf_polyline", "drivers_8h.html#a6f7823ce7862e60b817954c1f9842c9f", null ],
    [ "plbuf_restore", "drivers_8h.html#a4320599305a969571f4807dad3c9b07c", null ],
    [ "plbuf_save", "drivers_8h.html#a24123befa8ab7b32453afef5f2158e0a", null ],
    [ "plbuf_setsub", "drivers_8h.html#a32a028c4688be952a5d77b9d2769cb3f", null ],
    [ "plbuf_ssub", "drivers_8h.html#af963096c753291574b24ee10ff1e8a75", null ],
    [ "plbuf_state", "drivers_8h.html#a04fc5b733e9276237fbc0504ad2913b0", null ],
    [ "plbuf_switch", "drivers_8h.html#ab99f4584f81ede6fbf759adf119c7908", null ],
    [ "plbuf_tidy", "drivers_8h.html#a8380d3bdc75eaaccdc69f3787f94c6d5", null ],
    [ "plD_dispatch_init_aqt", "drivers_8h.html#a1dd3e763078e0cfd82fc4cede1366a2f", null ],
    [ "plD_dispatch_init_bmpqt", "drivers_8h.html#a4062d0c531ed86d131ca59ecb6eab6c6", null ],
    [ "plD_dispatch_init_cgm", "drivers_8h.html#ad2370d582e90e5d9391ebb40fecc9f63", null ],
    [ "plD_dispatch_init_epscairo", "drivers_8h.html#a572957dd71374a028b5ad116d3eece58", null ],
    [ "plD_dispatch_init_epsqt", "drivers_8h.html#a99a16338347aad1e7449b3a8d141cda8", null ],
    [ "plD_dispatch_init_extcairo", "drivers_8h.html#a8ca0406b19d7147104f78445e45b9b41", null ],
    [ "plD_dispatch_init_extqt", "drivers_8h.html#ab6e8ef8442c14ceb04124a0ae2ff6b0b", null ],
    [ "plD_dispatch_init_gif", "drivers_8h.html#a5b230a0fcfc5a3e0cd2adb40799180ee", null ],
    [ "plD_dispatch_init_jpeg", "drivers_8h.html#aae1abaa1ae115790e0d5aff2238f6b93", null ],
    [ "plD_dispatch_init_jpgqt", "drivers_8h.html#a3062b1d4c194820370e8b42c64ddff23", null ],
    [ "plD_dispatch_init_mem", "drivers_8h.html#a67f4d05ad2d4db16d2e893feafbc33db", null ],
    [ "plD_dispatch_init_memcairo", "drivers_8h.html#a3e723b08dc17e693d88c3c94a319eef0", null ],
    [ "plD_dispatch_init_memqt", "drivers_8h.html#aff1942bf49686ddb0d2f83b67cddf875", null ],
    [ "plD_dispatch_init_ntk", "drivers_8h.html#a5491405dbf712573a0a84a2a27b6d0ee", null ],
    [ "plD_dispatch_init_null", "drivers_8h.html#a4f69c62a1b6fed53e9a93076adebd89d", null ],
    [ "plD_dispatch_init_pdf", "drivers_8h.html#a263a541692dfe644c10d499513248d15", null ],
    [ "plD_dispatch_init_pdfcairo", "drivers_8h.html#aa502a88f00f7811379e1815ccb4dc9e2", null ],
    [ "plD_dispatch_init_pdfqt", "drivers_8h.html#a96f4eac8f7aaadfc0e7e14e3c28a065e", null ],
    [ "plD_dispatch_init_plm", "drivers_8h.html#af9aff741079c9e244d5befa19e282b06", null ],
    [ "plD_dispatch_init_png", "drivers_8h.html#ab75a4531f6991f45527038c884d3e9ae", null ],
    [ "plD_dispatch_init_pngcairo", "drivers_8h.html#ae92cfcea34206e50c1f348bf5a7cab24", null ],
    [ "plD_dispatch_init_pngqt", "drivers_8h.html#a117e5dda7fdf96287d823048aa87faec", null ],
    [ "plD_dispatch_init_ppmqt", "drivers_8h.html#a0ebb7f8a5d527714eb0e61386a160737", null ],
    [ "plD_dispatch_init_psc", "drivers_8h.html#a35794dc16d2622504190642b1b44c811", null ],
    [ "plD_dispatch_init_pscairo", "drivers_8h.html#ad5eddd212d165f2593a750142bdd3beb", null ],
    [ "plD_dispatch_init_psm", "drivers_8h.html#a8e9d129cfa3d1baa697f2659f092e3e4", null ],
    [ "plD_dispatch_init_pstex", "drivers_8h.html#a5a885f0fd5006f13c3a0cc6c0d99f0c5", null ],
    [ "plD_dispatch_init_psttfc", "drivers_8h.html#a6bf017d91756e4a3b9d00fd8ce00157e", null ],
    [ "plD_dispatch_init_psttfm", "drivers_8h.html#a67198a37c43e5c73662c16adcf32f288", null ],
    [ "plD_dispatch_init_qtwidget", "drivers_8h.html#ac0db04e91dac28bcc98a2effd3e6b8a3", null ],
    [ "plD_dispatch_init_svg", "drivers_8h.html#a781b47baccdb0fe6b2c0f86549de22b7", null ],
    [ "plD_dispatch_init_svgcairo", "drivers_8h.html#a1879d7f70ad6a5c77d928b9a29c58bf7", null ],
    [ "plD_dispatch_init_svgqt", "drivers_8h.html#a5fcf3fd321348aaa999ae8497067ea4e", null ],
    [ "plD_dispatch_init_tiffqt", "drivers_8h.html#ab013b8c4f62c7614ff23a11a7073e788", null ],
    [ "plD_dispatch_init_tk", "drivers_8h.html#a23f2027a53580bef3fdf644cff59a546", null ],
    [ "plD_dispatch_init_tkwin", "drivers_8h.html#a3f2e204449ada39332146b4ad295c62e", null ],
    [ "plD_dispatch_init_wincairo", "drivers_8h.html#a19fb6c19ab899d28508265cce95b7e1b", null ],
    [ "plD_dispatch_init_wingcc", "drivers_8h.html#a2b7e1212a714523a0f8a69116efcc457", null ],
    [ "plD_dispatch_init_wxpng", "drivers_8h.html#a943b765ed6013ba7dba377f8f558ff86", null ],
    [ "plD_dispatch_init_wxwidgets", "drivers_8h.html#a372b75bf2e0b7b185b0ef44933b1e730", null ],
    [ "plD_dispatch_init_xcairo", "drivers_8h.html#a08d56c4df48e49adef57ff3410fd4d33", null ],
    [ "plD_dispatch_init_xfig", "drivers_8h.html#a7b3cadd1f9bb676fc12b3cc3d96d0be3", null ],
    [ "plD_dispatch_init_xw", "drivers_8h.html#aa754ac9324e9e8c68c6fed27c9efa204", null ],
    [ "plFlushBuffer", "drivers_8h.html#a3356f1609c863412f0ef0c9519249011", null ],
    [ "plRemakePlot", "drivers_8h.html#a1f4b01b8bacb7f80e2e1b261c0acbdf7", null ]
];
